import React, { Component } from 'react';
import styles from './style.css';
import addimgIcon from './images/add_pic_bg@2x.png';
import delIcon from './images/delete_pic_btn@2x.png';

class ImagePicker extends Component {
  constructor(props) {
    super(props);
    this.state = {
      done: false,
      hasValue:
        Object.keys(props).find(i => i === 'value') === -1 ? false : true,
      files: [],
    };
  }
  shouldComponentUpdate(nextProps, nextState) {
    const { value } = nextProps;
    const { files } = nextState;
    if (!value && files.length) {
      this.deleteImage();
    }
    return true;
  }
  selectImage = () => {
    const { done } = this.state;
    const { showView } = this.props;
    if (done) {
      showView();
    } else {
      this.refs.input.dispatchEvent(new MouseEvent('click'));
    }
  };
  deleteImage = e => {
    e && e.stopPropagation();
    const { onChange } = this.props;
    console.log('del');
    this.refs.input.value = '';
    this.setState(() => ({
      files: [],
      done: false,
    }));
    if (onChange) {
      onChange(null);
    }
  };
  uploadImg = e => {
    const { onChange } = this.props;
    const filesList = e.target.files;
    const fileUrl = this.createObjectURL(filesList[0]);
    this.setState(() => ({
      files: [fileUrl],
      done: true,
    }));
    if (onChange) {
      onChange({
        filesList,
        url: fileUrl,
      });
    }
  };
  createObjectURL = blob => {
    if (window.URL) {
      return window.URL.createObjectURL(blob);
    } else if (window.webkitURL) {
      return window.webkitURL.createObjectURL(blob);
    }
    return null;
  };
  revokeObjectURL = url => {
    if (window.URL) {
      return window.URL.revokeObjectURL(url);
    } else if (window.webkitURL) {
      return window.webkitURL.revokeObjectURL(url);
    }
  };
  render() {
    const { className } = this.props;
    const { files, done } = this.state;
    return (
      <div
        className={
          className ? `${className} ${styles.imageWrap}` : styles.imageWrap
        }
        onClick={this.selectImage}
      >
        {done ? (
          <img className={styles.innerImg} src={files[0]} alt="" />
        ) : (
          <img src={addimgIcon} alt="" />
        )}
        {done && (
          <img
            src={delIcon}
            className={styles.delBtn}
            alt=""
            onClick={this.deleteImage}
          />
        )}
        <input
          ref="input"
          type="file"
          accept="image/*"
          onChange={this.uploadImg}
          style={{ display: 'none' }}
        />
      </div>
    );
  }
}

export default ImagePicker;
