import React, { Component } from 'react';
import { ListView, PullToRefresh, Modal, Toast } from 'antd-mobile';
import styles from './style.css';
import RepairItem from './components/RepairItem';
import { fetchRepairList } from '../../api/index';
import Perview from '../../components/Perview/Perview';

class RepairList extends Component {
  constructor(props) {
    super(props);
    const getSectionData = (dataBlob, sectionID) => dataBlob[sectionID];
    const getRowData = (dataBlob, sectionID, rowID) => dataBlob[rowID];
    const list = new ListView.DataSource({
      getRowData,
      getSectionHeaderData: getSectionData,
      rowHasChanged: (row1, row2) => row1 !== row2,
      sectionHeaderHasChanged: (s1, s2) => s1 !== s2,
    });
    this.state = {
      refreshing: false,
      down: true,
      height: document.documentElement.clientHeight,
      pagination: {
        nowDate: '',
        pageNum: 1,
        pageSize: 50,
      },
      list: list,
      perviewVisibility: false,
      selectedImgList: [],
      perviewIndex: 0,
    };
  }
  componentDidMount() {
    let wrap = document.querySelector('.RepairContent');
    const hei = wrap.clientHeight;
    setTimeout(
      () =>
        this.setState({
          height: hei,
        }),
      0
    );
    const { pagination } = this.state;
    const nowDate = new Date().toISOString();
    fetchRepairList({
      ...pagination,
      nowDate,
    })
      .then(res => {
        console.log(res);
        this.setState(({ pagination }) => ({
          list: res.data,
          pagination: {
            ...pagination,
            nowDate,
          },
        }));
      })
      .catch(err => {
        Toast.fail(err.msg || '请求失败！');
        this.setState({
          refreshing: false,
        });
      });
  }
  refreshHandle = () => {
    this.setState({ refreshing: true });
    const { pagination } = this.state;
    fetchRepairList({
      ...pagination,
      pageNum: pagination.pageNum + 1,
    })
      .then(res => {
        console.log(res);
        if (res.data.length) {
          this.setState(({ list, pagination }) => ({
            refreshing: false,
            list: [...list, ...res.data],
            pagination: {
              ...pagination,
              pageNum: pagination.pageNum + 1,
            },
          }));
        } else {
          this.setState({
            refreshing: false,
          });
        }
      })
      .catch(err => {
        Toast.fail(err.msg || '请求失败！');
        this.setState({
          refreshing: false,
        });
      });
  };
  showViewHandle = (list, index) => {
    this.setState({
      perviewVisibility: true,
      perviewIndex: index,
      selectedImgList: list,
    });
  };
  resetDialog = () => {
    this.setState({
      perviewVisibility: false,
    });
  };
  render() {
    const {
      list,
      perviewVisibility,
      selectedImgList,
      perviewIndex,
    } = this.state;
    return (
      <div className={styles.repairList}>
        {/* <ListView
          style={{
            height: this.state.height,
          }}
          dataSource={list}
          renderRow={rowData => (
            <RepairItem
              key={rowData.id}
              data={rowData}
              showView={this.showViewHandle}
            />
          )}
        /> */}
        <PullToRefresh
          damping={60}
          ref={el => (this.ptr = el)}
          style={{
            height: this.state.height,
            overflow: 'auto',
          }}
          indicator={{ deactivate: '上拉可以刷新' }}
          direction={'up'}
          refreshing={this.state.refreshing}
          onRefresh={this.refreshHandle}
        >
          <div className={styles.listInfo}>显示最近半年的报修记录</div>
          {list.length ? (
            list.map(i => (
              <RepairItem key={i.id} data={i} showView={this.showViewHandle} />
            ))
          ) : (
            <div className={styles.noData}>暂无数据</div>
          )}
        </PullToRefresh>
        <Modal
          className={styles.perViewDialog}
          visible={perviewVisibility}
          transparent
          maskClosable={true}
          onClose={this.resetDialog}
          title=""
        >
          <Perview data={selectedImgList} index={perviewIndex} />
        </Modal>
      </div>
    );
  }
}

export default RepairList;
